===============================
Configuration options reference
===============================

The following is an overview of all available configuration options in Nova
and compute-hyperv.
For a sample configuration file, refer to :ref:`config_sample`.

.. show-options::

    compute_hyperv
    os_win
    nova.conf
    oslo.log
    oslo.messaging
    oslo.concurrency
